@@ -1,4 +1,4 @@
-mest <- function(x, bend = 1.28, na.rm = FALSE){
+mest <- function(x, bend = 1.28, na.rm = FALSE, ...){
 #
 #  Compute M-estimator of location using Huber's Psi.
 #  The default bending constant is 1.28
@@ -18,4 +18,4 @@ if(abs(newmest-mest) <.0001)break
 mest<-newmest
 }
 mest
-}
\ No newline at end of file
+}
