@@ -1,5 +1,5 @@
-winmean <- function(x, tr = 0.2, na.rm = FALSE){
+winmean <- function(x, tr = 0.2, na.rm = FALSE, ...){
 if(na.rm)x=elimna(x)
 winmean<-mean(winval(x,tr))
 winmean
-}
\ No newline at end of file
+}
